@@ -3,16 +3,14 @@
 # TRUSTBE PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 #
 #
-import signal
-import threading
 
-import mesh.asm as asm
-import mesh.environ as env
-import mesh.log as log
+from mesh.asm import *
 from mesh.boost import *
 from mesh.cause import *
 from mesh.codec import *
 from mesh.context import *
+from mesh.environ import *
+from mesh.log import *
 from mesh.macro import *
 from mesh.mpc import *
 from mesh.prsim import *
@@ -35,7 +33,6 @@ __all__ = (
     "Filter",
     "Invocation",
     "Provider",
-    "Schema",
     "ServiceProxy",
     "MeshKey",
     "Mesh",
@@ -84,42 +81,27 @@ __all__ = (
     "Metadata",
 )
 
-__mesh_runtime__ = Mooter()
-
-from mesh.prsim.graphics import Graphics
+__mooter__ = Mooter()
 
 
 def init():
     asm.init()
 
 
-def start():
-    __mesh_runtime__.start()
+async def start():
+    await __mooter__.start()
 
 
-def refresh():
-    __mesh_runtime__.refresh()
+async def refresh():
+    await __mooter__.refresh()
 
 
-def stop():
-    __mesh_runtime__.stop()
+async def stop():
+    await __mooter__.stop()
 
 
-def wait():
+async def wait():
     """
     Use signal handler to throw exception which can be caught to allow graceful exit.
-    :return:
     """
-    waiter = threading.Event()
-
-    def signal_handler(signum, frame):
-        try:
-            stop()
-        finally:
-            waiter.set()
-
-    signal.signal(signal.SIGTERM, signal_handler)
-    try:
-        waiter.wait()
-    except KeyboardInterrupt:
-        log.info(f"{env.System.environ().get_mesh_name()} has been stop gracefully. ")
+    await __mooter__.wait()
