@@ -21,6 +21,7 @@ import mesh.prsim as prsim
 import mesh.runtime as runtime
 import mesh.schema as schema
 import mesh.system as system
+import mesh.telemetry as telemetry
 import mesh.tool as tool
 
 
@@ -43,3 +44,4 @@ def init():
     boost.init()
     context.init()
     environ.init()
+    telemetry.init()
