@@ -330,7 +330,7 @@ class ConsumerThread(object):
             name='{}_Consumer_{}'.format(disruptor.name, consumer), target=self.run)
         self.thread.start()
 
-    def run(self):
+    async def run(self):
         """
         Consume while there's something to consume!
         """
@@ -355,7 +355,7 @@ class ConsumerThread(object):
                             self, self.disruptor.time_fn() - s)
 
             # when data is available, consume it *outside* of lock!
-            self._consume_safe(to_consume)
+            await self._consume_safe(to_consume)
 
             # re-lock after consumption to update state
             with self.disruptor.sync:
@@ -369,22 +369,19 @@ class ConsumerThread(object):
         with self.disruptor.sync:
             available_count = self.disruptor.producer_seqnum - self.seqnum
             if available_count > 0:
-                to_consume = self.disruptor.ring_buffer.mget(
-                    self.seqnum, available_count)
-        self._consume_safe(to_consume)
-        self.consumer.close()
+                to_consume = self.disruptor.ring_buffer.mget(self.seqnum, available_count)
+        await self._consume_safe(to_consume)
+        await self.consumer.close()
 
-    def _consume_safe(self, elements):
+    async def _consume_safe(self, elements):
         if elements is not None and len(elements) > 0:
             s = self.disruptor.time_fn()
             try:
-                self.consumer.consume(elements)
+                await self.consumer.consume(elements)
             except Exception as e:
                 if self.disruptor.consumer_error_handler is not None:
-                    self.disruptor.consumer_error_handler(
-                        self.consumer, elements, e)
-            self.disruptor.stats.report_c_consumed(
-                self, len(elements), self.disruptor.time_fn() - s)
+                    self.disruptor.consumer_error_handler(self.consumer, elements, e)
+            self.disruptor.stats.report_c_consumed(self, len(elements), self.disruptor.time_fn() - s)
 
 
 class Disruptor(object):
@@ -530,7 +527,7 @@ class Consumer(object):
     A no-op consumer class; can be extended for convenience
     """
 
-    def consume(self, elements):
+    async def consume(self, elements):
         """
         Consume elements
         :param elements: a list of elements
@@ -538,7 +535,7 @@ class Consumer(object):
         """
         raise NotImplementedError()
 
-    def close(self):
+    async def close(self):
         """
         Close consumer, finishing any consumption tasks e.g. terminating batches
         """
@@ -563,14 +560,14 @@ class BatchConsumer(Consumer):
         self.batch_size = batch_size
         self._batch = []
 
-    def consume(self, elements):
+    async def consume(self, elements):
         consumed = 0
         while consumed < len(elements):
             to_consume_cnt = min(
                 self.batch_size - len(self._batch), len(elements) - consumed)
             self._batch.extend(elements[consumed:consumed + to_consume_cnt])
             if len(self._batch) >= self.batch_size:
-                self.consume_batch(self._batch)
+                await self.consume_batch(self._batch)
                 self._batch = []
             consumed += to_consume_cnt
 
@@ -578,7 +575,7 @@ class BatchConsumer(Consumer):
         if len(self._batch) > 0:
             self.consume_batch(self._batch)
 
-    def consume_batch(self, batch):
+    async def consume_batch(self, batch):
         """
         Consume a batch of elements
         :param batch: a batch of elements of batch_size or smaller
