@@ -94,6 +94,13 @@ class MeshCode(Codeable, Enum):
     ADDRESS_ERROR = "E0000000619", "地址非法或无法访问"
     UNEXPECTED_SYNTAX = "E0000000620", "规则语法错误"
     UNKNOWN_SCRIPT = "E0000000621", "规则不存在"
+    DATA_ID_ERROR = "E0000000622", "数据身份不存在或非法"
+    START_PENDING = "E0000000623", "系统启动中"
+    UNEXPECTED_SQL_SYNTAX = "E0000000624", "SQL语法错误"
+    NO_DATABASE = "E0000000625", "数据库不存在"
+    NO_TRANSACTION = "E0000000626", "事务不存在"
+    SQL_EXECUTE_ERROR = "E0000000627", "SQL执行异常"
+    DUPLICATE_KEY = "E0000000628", "唯一键冲突"
 
     def __init__(self, code: str, message: str) -> None:
         self.code = code
