@@ -85,16 +85,22 @@ class URI:
 
 class Mode(Enum):
     Disable = 1
-    Failfast = 2
-    Nolog = 4
-    JsonLogFormat = 8
-    RCache = 16
-    PHeader = 32
-    Metrics = 64
-    RLog = 128
-    MGrpc = 256
-    PermitCirculate = 512
-    NoStdColor = 1024
+    Failfast = 1 << 1
+    Nolog = 1 << 2
+    JsonLogFormat = 1 << 3
+    RCache = 1 << 4
+    PHeader = 1 << 5
+    Metrics = 1 << 6
+    RLog = 1 << 7
+    Debug = 1 << 8
+    PermitCirculate = 1 << 9
+    NoStdColor = 1 << 10
+    Isolate = 1 << 11
+    DisableTee = 1 << 12
+    WebVip = 1 << 13
+    OpenTelemetry = 1 << 14
+    NoLicCheck = 1 << 15
+    AllowCross = 1 << 16
 
     def __init__(self, v: int) -> None:
         self.v = v
@@ -107,14 +113,23 @@ class Mode(Enum):
 
 
 class Environ:
-    __mesh_address_keys = ['mesh.address', 'mesh_address', 'mesh-address', 'MESH_ADDRESS']
-    __mesh_runtime_keys = ['mesh.runtime', 'mesh_runtime', 'mesh-runtime', 'MESH_RUNTIME']
-    __mesh_mode_keys = ['mesh.mode', 'mesh_mode', 'mesh-mode', 'MESH_MODE']
-    __mesh_name_keys = ['mesh.name', 'mesh_name', 'mesh-name', 'MESH_NAME']
-    __mesh_direct_keys = ['mesh.direct', 'mesh_direct', 'mesh-direct', 'MESH_DIRECT']
-    __mesh_subset_keys = ['mesh.subset', 'mesh_subset', 'mesh-subset', 'MESH_SUBSET']
-    __mesh_min_channels = ['mesh.grpc.channel.rpc.min', 'mesh_grpc_channel_rpc_min', 'MESH_GRPC_CHANNEL_RPC_MIN']
-    __mesh_max_channels = ['mesh.grpc.channel.rpc.max', 'mesh_grpc_channel_rpc_max', 'MESH_GRPC_CHANNEL_RPC_MAX']
+    __mesh_address_keys = ['MESH_ADDRESS', 'mesh.address', 'mesh_address', 'mesh-address']
+    __mesh_runtime_keys = ['MESH_RUNTIME', 'mesh.runtime', 'mesh_runtime', 'mesh-runtime']
+    __mesh_mode_keys = ['MESH_MODE', 'mesh.mode', 'mesh_mode', 'mesh-mode']
+    __mesh_name_keys = ['MESH_NAME', 'mesh.name', 'mesh_name', 'mesh-name']
+    __mesh_direct_keys = ['MESH_DIRECT', 'mesh.direct', 'mesh_direct', 'mesh-direct']
+    __mesh_subset_keys = ['MESH_SUBSET', 'mesh.subset', 'mesh_subset', 'mesh-subset']
+    __mesh_min_channels = ['MESH_GRPC_CHANNEL_RPC_MIN', 'mesh.grpc.channel.rpc.min', 'mesh_grpc_channel_rpc_min']
+    __mesh_max_channels = ['MESH_GRPC_CHANNEL_RPC_MAX', 'mesh.grpc.channel.rpc.max', 'mesh_grpc_channel_rpc_max']
+    __mesh_proc_keys = ['MESH_PROC', 'mesh.proc', 'mesh_proc', 'MESH.PROC']
+    # # compat otel config
+    __open_telemetry_endpoint = ['open.telemetry.endpoint', 'open_telemetry_endpoint', 'OPEN_TELEMETRY_ENDPOINT',
+                                 'OTEL_EXPORTER_OTLP_ENDPOINT', 'OTEL_EXPORTER_OTLP_TRACES_ENDPOINT']
+    # # compat otel config
+    __open_telemetry_protocol = ['open.telemetry.protocol', 'open_telemetry_protocol', 'OPEN_TELEMETRY_PROTOCOL']
+    __print_telemetry_std = ['print.telemetry.std', 'print_telemetry_std', 'PRINT_TELEMETRY_STD']
+    # # simple or batch, default simple
+    __open_telemetry_proc_type = ['open.telemetry.proc.type', 'open_telemetry_proc_type', 'OPEN_TELEMETRY_PROC_TYPE']
 
     @staticmethod
     def get_default_mesh_port() -> int:
@@ -138,8 +153,9 @@ class Environ:
         parser.add_argument("--mesh.enable", type=str, default='', required=False)
         parser.add_argument("--mesh.name", type=str, default='', required=False)
         parser.add_argument("--mesh.direct", type=str, default='', required=False)
-        parser.add_argument("--mesh.grpc.channel.rpc.min", type=int, default=3, required=False)
-        parser.add_argument("--mesh.grpc.channel.rpc.max", type=int, default=3, required=False)
+        parser.add_argument("--mesh.grpc.channel.rpc.min", type=int, default=f'{os.cpu_count() * 2}', required=False)
+        parser.add_argument("--mesh.grpc.channel.rpc.max", type=int, default=f'{os.cpu_count() * 2}', required=False)
+        parser.add_argument("--mesh.procs", type=int, default=-1, required=False)
         args, _ = parser.parse_known_args()
         return vars(args)
 
@@ -178,6 +194,10 @@ class Environ:
     def get_min_channels(self) -> int:
         return int(self.get_property('3', self.__mesh_min_channels))
 
+    @Cache
+    def get_proc(self) -> int:
+        return int(self.get_property('-1', self.__mesh_proc_keys))
+
     @Cache
     def get_hostname(self) -> str:
         return socket.gethostname()
@@ -207,16 +227,37 @@ class Environ:
             s.bind(('', 0))
             return s.getsockname()[1]
 
+    @Cache
+    def enable_telemetry(self) -> bool:
+        # enable only for set on and telemetry endpoint valid
+        return self.get_telemetry_endpoint() != ''
+
+    @Cache
+    def get_telemetry_endpoint(self) -> str:
+        return self.get_property('', self.__open_telemetry_endpoint)
+
+    @Cache
+    def get_telemetry_protocol(self) -> str:
+        return self.get_property('grpc', self.__open_telemetry_protocol)
+
+    @Cache
+    def enable_telemetry_std(self) -> bool:
+        # if print telemetry to stdout
+        return self.get_property('0', self.__print_telemetry_std) == '1'
+
+    @Cache
+    def get_telemetry_proc_type(self) -> str:
+        return self.get_property('simple', self.__open_telemetry_proc_type)
+
 
 __environ__ = Environ()
-__mode__ = int(__environ__.get_mesh_mode())
 
 
 class System:
 
     @staticmethod
     def mode() -> int:
-        return __mode__
+        return int(__environ__.get_mesh_mode())
 
     @staticmethod
     def environ() -> Environ:
