@@ -7,7 +7,7 @@
 from mesh.grpx.bindservice import GrpcBindableService
 from mesh.grpx.channels import GrpcChannels
 from mesh.grpx.consumer import GrpcConsumer
-from mesh.grpx.interceptor import GrpcInterceptor
+from mesh.grpx.interceptor import GrpcInterceptor, AsyncGrpcInterceptor
 from mesh.grpx.marshaller import GrpcMarshaller
 from mesh.grpx.provider import GrpcProvider
 
@@ -18,6 +18,7 @@ __all__ = (
     "GrpcChannels",
     "GrpcConsumer",
     "GrpcInterceptor",
+    "AsyncGrpcInterceptor",
     "GrpcMarshaller",
     "GrpcProvider"
 )
