@@ -3,8 +3,7 @@
 # TRUSTBE PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 #
 #
-import queue
-from typing import Dict, Iterator, Any
+from typing import Dict, Iterator, Any, AsyncIterator
 
 import grpc
 
@@ -32,33 +31,14 @@ class GrpcBindableService(grpc.GenericRpcHandler):
     def service(self, handler_call_details):
         return self.handlers.service(handler_call_details)
 
-    @staticmethod
-    def stream_stream(iterator, ctx: grpc.ServicerContext) -> Iterator[Any]:
-        return Transformer(iterator, ctx)
-
-
-class Transformer(Iterator[Any]):
-
-    def __init__(self, iterator: Iterator[Any], ctx: grpc.ServicerContext):
-        self.iterator = iterator
-        self.grpc_ctx = ctx
-        self.transporter = ServiceLoader.load(Transporter).get(PROVIDER)
-        self.mesh_ctx = self.context(ctx)
-
-    def __next__(self) -> Any:
-        buff = next(self.iterator)
-        return self.transporter.transport(self.mesh_ctx, self.mesh_ctx.get_urn(), buff)
-
-    def on_error(self, e: BaseException):
-        """"""
-        pass
-
-    def on_complete(self):
-        """"""
-        pass
+    async def stream_stream(self, iterator: AsyncIterator[Any], ctx: grpc.aio.ServicerContext):
+        ctx = self.context(ctx)
+        transporter = ServiceLoader.load(Transporter).get(PROVIDER)
+        async for buff in iterator:
+            yield await transporter.transport(ctx, ctx.get_urn(), buff)
 
     @staticmethod
-    def context(ctx: grpc.ServicerContext) -> Context:
+    def context(ctx: grpc.aio.ServicerContext) -> Context:
         metadata = ctx.invocation_metadata()
         if metadata is None:
             return MeshContext.create()
@@ -79,3 +59,17 @@ class Transformer(Iterator[Any]):
                 continue
             mtx.attachments[std_name] = value
         return mtx
+
+
+class Transformer(Iterator[Any]):
+    def __init__(self, iterator: Iterator[Any], ctx: Context):
+        self.iterator = iterator
+        self.transporter = ServiceLoader.load(Transporter).get(PROVIDER)
+        self.ctx = ctx
+
+    def __iter__(self):
+        return self
+
+    def __next__(self):
+        buff = next(self.iterator)
+        return self.transporter.transport(self.ctx, self.ctx.get_urn(), buff)
