@@ -5,12 +5,15 @@
 #
 
 import random
-from typing import Any, List, Dict, Callable
+from typing import Any, List, Dict, Callable, Optional
 
 import grpc
+from grpc import Compression
+from grpc.aio import Channel, insecure_channel, StreamStreamMultiCallable, StreamUnaryMultiCallable, \
+    UnaryStreamMultiCallable, UnaryUnaryMultiCallable, StreamStreamCall
 
 import mesh.tool as tool
-from mesh.grpx.interceptor import GrpcInterceptor
+from mesh.grpx.interceptor import AsyncGrpcInterceptor
 from mesh.grpx.marshaller import GrpcMarshaller
 
 
@@ -21,7 +24,7 @@ class GrpcChannels:
         self.marshaller = GrpcMarshaller()
         self.serializer = self.marshaller.serialize
         self.deserializer = self.marshaller.deserialize
-        self.interceptor = GrpcInterceptor()
+        self.interceptor = AsyncGrpcInterceptor()
         self.path = "/mesh-rpc/v1"
         self.streams: Dict[str, GrpcMultiplexStream] = dict()
 
@@ -39,80 +42,87 @@ class GrpcChannels:
         channel = self.create_if_absent(address)
         return channel.stream_stream(self.path, self.serializer, self.deserializer)
 
-    def unary(self, address: str, inbound: bytes, timeout: Any, metadata: Any) -> bytes:
+    async def unary(self, address: str, inbound: bytes, timeout: Any, metadata: Any) -> bytes:
         channel = self.create_if_absent(address)
-        conn: grpc.UnaryUnaryMultiCallable = channel.unary_unary(self.path, self.serializer, self.deserializer)
-        return conn(inbound, timeout, metadata, None, True, False)
+        c = channel.unary_unary(self.path, self.serializer, self.deserializer)
+        return await c(inbound, timeout=timeout, metadata=metadata, wait_for_ready=True, compression=Compression.Gzip)
 
-    def stream(self, address: str, inbound: bytes, timeout: Any, metadata: Any) -> bytes:
+    async def stream(self, address: str, inbound: bytes, timeout: Any, metadata: Any) -> bytes:
         stream = self.streams.get(address, None)
         if stream is None:
             stream = self.streams[address] = GrpcMultiplexStream(address, lambda addr: self.create_stream(addr))
-        return stream.next(inbound, timeout, metadata)
+        return await anext(aiter(stream.next(inbound, timeout, metadata)))
 
 
 class GrpcMultiplexStream:
 
-    def __init__(self, address: str, streamer: Callable[[str], grpc.StreamStreamMultiCallable]):
+    def __init__(self, address: str, streamer: Callable[[str], StreamStreamMultiCallable]):
         self.address = address
         self.stream = streamer(address)
         self.streamer = streamer
 
-    def next(self, inbound: bytes, timeout: Any, metadata: Any) -> bytes:
-        return self.stream(inbound, timeout, metadata, None, True, False)
+    def next(self, inbound: bytes, timeout: Any, metadata: Any) -> StreamStreamCall:
+        return self.stream(inbound, timeout, metadata, None, True, Compression.Gzip)
 
 
-class GrpcMultiplexChannel(grpc.Channel):
+class GrpcMultiplexChannel(Channel):
     """
     https://github.com/grpc/grpc/blob/598e171746576c5398388a4c170ddf3c8d72b80a/include/grpc/impl/codegen/grpc_types.h#L170
     """
 
-    def close(self):
-        for _, channel in self.channels:
-            channel.close()
-
-    def subscribe(self, callback, try_to_connect=False):
-        return self.select().subscribe(callback, try_to_connect)
-
-    def unsubscribe(self, callback):
-        return self.select().unsubscribe(callback)
-
-    def unary_unary(self, method, request_serializer=None, response_deserializer=None):
-        return self.select().unary_unary(method, request_serializer, response_deserializer)
-
-    def unary_stream(self, method, request_serializer=None, response_deserializer=None):
-        return self.select().unary_stream(method, request_serializer, response_deserializer)
-
-    def stream_unary(self, method, request_serializer=None, response_deserializer=None):
-        return self.select().stream_unary(method, request_serializer, response_deserializer)
-
-    def stream_stream(self, method, request_serializer=None, response_deserializer=None):
-        return self.select().stream_stream(method, request_serializer, response_deserializer)
-
-    def __enter__(self):
-        for _, channel in self.channels:
-            channel.__enter__()
-
-    def __exit__(self, exc_type, exc_val, exc_tb):
-        for _, channel in self.channels:
-            channel.__exit__(exc_type, exc_val, exc_tb)
-
     def __init__(self, address: str, *interceptors):
         self.address = address
         self.interceptors = interceptors
-        self.channels: List[grpc.Channel] = []
+        self.channels: List[Channel] = []
         self.compression_options = {
             "none": grpc.Compression.NoCompression,
             "gzip": grpc.Compression.Gzip,
         }
 
+    async def __aenter__(self):
+        for channel in self.channels:
+            await channel.__aenter__()
+
+    async def __aexit__(self, exc_type, exc_val, exc_tb):
+        for channel in self.channels:
+            await channel.__aexit__(exc_type, exc_val, exc_tb)
+
+    async def close(self, grace: Optional[float] = None):
+        for channel in self.channels:
+            await channel.close()
+
+    def get_state(self, try_to_connect: bool = False) -> grpc.ChannelConnectivity:
+        return self.select().get_state(try_to_connect)
+
+    async def wait_for_state_change(self, last_observed_state: grpc.ChannelConnectivity) -> None:
+        await self.select().wait_for_state_change(last_observed_state)
+
+    async def channel_ready(self) -> None:
+        await self.select().channel_ready()
+
+    def unary_unary(self, method: str, request_serializer: Optional[Any] = None,
+                    response_deserializer: Optional[Any] = None) -> UnaryUnaryMultiCallable:
+        return self.select().unary_unary(method, request_serializer, response_deserializer)
+
+    def unary_stream(self, method: str, request_serializer: Optional[Any] = None,
+                     response_deserializer: Optional[Any] = None) -> UnaryStreamMultiCallable:
+        return self.select().unary_stream(method, request_serializer, response_deserializer)
+
+    def stream_unary(self, method: str, request_serializer: Optional[Any] = None,
+                     response_deserializer: Optional[Any] = None) -> StreamUnaryMultiCallable:
+        return self.select().stream_unary(method, request_serializer, response_deserializer)
+
+    def stream_stream(self, method: str, request_serializer: Optional[Any] = None,
+                      response_deserializer: Optional[Any] = None) -> StreamStreamMultiCallable:
+        return self.select().stream_stream(method, request_serializer, response_deserializer)
+
     def default_compression(self) -> Any:
         return self.compression_options["gzip"]
 
     def reset(self, channel: grpc.Channel):
         self.channels.append(channel)
 
-    def select(self) -> grpc.Channel:
+    def select(self) -> Channel:
         """
         grpc.ssl_target_name_override
         grpc.default_authority
@@ -124,8 +134,8 @@ class GrpcMultiplexChannel(grpc.Channel):
 
         for _ in range(tool.get_max_channels()):
             options = self.default_options()
-            channel = grpc.insecure_channel(self.address, options, compression=self.default_compression())
-            self.channels.append(grpc.intercept_channel(channel, *self.interceptors))
+            channel = insecure_channel(self.address, options, self.default_compression(), self.interceptors)
+            self.channels.append(channel)
 
         return self.channels[random.randint(0, self.channels.__len__() - 1)]
 
