@@ -4,8 +4,11 @@
 #
 #
 import collections
+from typing import Callable, Union, Awaitable
 
 import grpc
+from grpc.aio import UnaryUnaryCall, UnaryStreamCall, StreamUnaryCall, StreamStreamCall
+from grpc.aio._typing import ResponseIterableType, RequestType, ResponseType, RequestIterableType
 
 import mesh.tool as tool
 from mesh.mpc import Mesh
@@ -19,11 +22,7 @@ class ClientCallDetails(
     pass
 
 
-class GrpcInterceptor(grpc.ServerInterceptor,
-                      grpc.StreamStreamClientInterceptor,
-                      grpc.StreamUnaryClientInterceptor,
-                      grpc.UnaryStreamClientInterceptor,
-                      grpc.UnaryUnaryClientInterceptor, ):
+class MeshInterceptor:
     TKeys = [
         Metadata.MESH_INCOMING_PROXY,
         Metadata.MESH_OUTGOING_PROXY,
@@ -64,6 +63,18 @@ class GrpcInterceptor(grpc.ServerInterceptor,
         credentials = context.credentials if hasattr(context, 'credentials') else None
         return ClientCallDetails(context.method, context.timeout, metadata, credentials, wait_for_ready, compression)
 
+    @staticmethod
+    def server_context(handler_call_details):
+        pass
+
+
+class GrpcInterceptor(MeshInterceptor,
+                      grpc.ServerInterceptor,
+                      grpc.StreamStreamClientInterceptor,
+                      grpc.StreamUnaryClientInterceptor,
+                      grpc.UnaryStreamClientInterceptor,
+                      grpc.UnaryUnaryClientInterceptor, ):
+
     def intercept_stream_stream(self, continuation, client_call_details, request_iterator):
         return continuation(self.client_context(client_call_details), request_iterator)
 
@@ -80,6 +91,37 @@ class GrpcInterceptor(grpc.ServerInterceptor,
         self.server_context(handler_call_details)
         return continuation(handler_call_details)
 
-    @staticmethod
-    def server_context(handler_call_details):
-        pass
+
+class AsyncGrpcInterceptor(MeshInterceptor,
+                           grpc.aio.ServerInterceptor,
+                           grpc.aio.StreamStreamClientInterceptor,
+                           grpc.aio.StreamUnaryClientInterceptor,
+                           grpc.aio.UnaryStreamClientInterceptor,
+                           grpc.aio.UnaryUnaryClientInterceptor, ):
+
+    async def intercept_service(self,
+                                continuation: Callable[[grpc.HandlerCallDetails], Awaitable[grpc.RpcMethodHandler]],
+                                caller: grpc.HandlerCallDetails) -> grpc.RpcMethodHandler:
+        self.server_context(caller)
+        return await continuation(caller)
+
+    async def intercept_stream_stream(self, continuation: Callable[
+        [ClientCallDetails, RequestType], StreamStreamCall
+    ], client_call_details: ClientCallDetails, request_iterator: RequestIterableType) -> Union[
+        ResponseIterableType, StreamStreamCall]:
+        return continuation(self.client_context(client_call_details), request_iterator)
+
+    async def intercept_stream_unary(self, continuation: Callable[
+        [ClientCallDetails, RequestType], StreamUnaryCall
+    ], client_call_details: ClientCallDetails, request_iterator: RequestIterableType) -> StreamUnaryCall:
+        return await continuation(self.client_context(client_call_details), request_iterator)
+
+    async def intercept_unary_stream(self, continuation: Callable[
+        [ClientCallDetails, RequestType], UnaryStreamCall
+    ], client_call_details: ClientCallDetails, request: RequestType) -> Union[ResponseIterableType, UnaryStreamCall]:
+        return continuation(self.client_context(client_call_details), request)
+
+    async def intercept_unary_unary(self, continuation: Callable[
+        [ClientCallDetails, RequestType], UnaryUnaryCall
+    ], client_call_details: ClientCallDetails, request: RequestType) -> Union[UnaryUnaryCall, ResponseType]:
+        return await continuation(self.client_context(client_call_details), request)
