@@ -23,5 +23,5 @@ class HTTPConsumer(Consumer):
     def start(self):
         pass
 
-    def consume(self, address: str, urn: str, execution: Execution[Reference], inbound: bytes) -> Future:
+    async def consume(self, address: str, urn: str, execution: Execution[Reference], inbound: bytes) -> Future:
         pass
