@@ -13,8 +13,16 @@ from mesh.mpc import Provider
 @spi("http")
 class HTTPProvider(Provider):
 
-    def start(self, address: str, tc: Any):
+    def __init__(self):
+        self.address = ""
+
+    async def start(self, address: str, tc: Any):
+        self.address = address
         log.info(f"Listening and serving HTTP 1.x on {address}")
 
-    def close(self):
-        log.info(f"Graceful stop HTTP 1.x serving")
+    async def close(self):
+        log.info(f"Graceful stop HTTP 1.x serving on {self.address}")
+
+    async def wait(self):
+        """"""
+        pass
