@@ -84,7 +84,7 @@ class Event:
         return Entity()
 
     @staticmethod
-    def new_instance(payload: Any, topic: Topic) -> "Event":
+    async def new_instance(payload: Any, topic: Topic) -> "Event":
         """
         Create local event instance.
         :param payload:
@@ -92,14 +92,14 @@ class Event:
         :return:
         """
         from mesh.prsim.network import Network
-        network = ServiceLoader.load(Network).get_default()
+        environ = await ServiceLoader.load(Network).get_default().get_environ()
         target = Principal()
-        target.node_id = network.get_environ().node_id
-        target.inst_id = network.get_environ().inst_id
-        return Event.new_instance_with_target(payload, topic, target)
+        target.node_id = environ.node_id
+        target.inst_id = environ.inst_id
+        return await Event.new_instance_with_target(payload, topic, target)
 
     @staticmethod
-    def new_instance_with_target(payload: Any, topic: Topic, target: Principal) -> "Event":
+    async def new_instance_with_target(payload: Any, topic: Topic, target: Principal) -> "Event":
         """
         Create any node event instance.
         :param payload:
@@ -108,10 +108,10 @@ class Event:
         :return:
         """
         from mesh.prsim.network import Network
-        network = ServiceLoader.load(Network).get_default()
+        environ = await ServiceLoader.load(Network).get_default().get_environ()
         source = Principal()
-        source.node_id = network.get_environ().node_id
-        source.inst_id = network.get_environ().inst_id
+        source.node_id = environ.node_id
+        source.inst_id = environ.inst_id
         return Event.new_instance_with_target_source(payload, topic, target, source)
 
     @staticmethod
