@@ -20,3 +20,7 @@ class Institution:
     @index(10)
     def inst_name(self) -> str:
         return ''
+
+    @index(15)
+    def status(self) -> int:
+        return 0
