@@ -34,8 +34,8 @@ class Reference:
         return ''
 
     @index(30)
-    def asyncable(self) -> bool:
-        return True
+    def flags(self) -> int:
+        return 0
 
     @index(35)
     def timeout(self) -> int:
