@@ -40,5 +40,5 @@ def stack(fmt: str, *args: object):
     mog.debug(fmt, args)
 
 
-def level(lev: int):
+def level(lev: Level):
     mog.level(lev)
