@@ -84,11 +84,16 @@ class NopLogger(Logger):
 
         self.do_write(level, msg.getvalue(), throwable)
 
-    @staticmethod
-    def do_write(level: Level, msg: str, e: bool = False):
-        frame = inspect.stack()[4]
-        index = frame.filename.rindex("/")
-        name = frame.filename[0 if index < 0 else index + 1:]
-        print(f"{datetime.now().strftime('%Y-%m-%d %H:%M:%S')} {level.name} {msg} {name}:{frame.lineno}")
+    def do_write(self, level: Level, msg: str, e: bool = False):
+        print(f"{datetime.now().strftime('%Y-%m-%d %H:%M:%S')} {level.name} {msg}{self.stack_tuple()}")
         if e:
             print(traceback.format_exc())
+
+    @staticmethod
+    def stack_tuple() -> str:
+        if not Mode.Metrics.enable():
+            return ""
+        frame = inspect.stack()[5]
+        index = frame.filename.rindex("/")
+        name = frame.filename[0 if index < 0 else index + 1:]
+        return f" {name}:{frame.lineno}"
