@@ -11,8 +11,8 @@ from mesh.macro.ark import T, ark
 
 class Binding(Generic[T]):
 
-    def __init__(self, fn: T = None, topic='', code='', version='', proto='grpc', codec='json',
-                 asyncable=True, timeout=10000, meshable=True):
+    def __init__(self, fn: T = None, topic='', code='', version='', proto='grpc', codec='json', flags=0, timeout=10000,
+                 meshable=True):
         """
         Metadata annotation for Serial Peripheral Interface. Can be used with {@link ServiceLoader#load(Class)}
         or dependency injection at compile time and runtime time.
@@ -22,7 +22,7 @@ class Binding(Generic[T]):
         self.version = version
         self.proto = proto
         self.codec = codec
-        self.asyncable = asyncable
+        self.flags = flags
         self.timeout = timeout
         self.meshable = meshable
         if topic != '':
@@ -63,8 +63,8 @@ class Binding(Generic[T]):
         return False
 
 
-def binding(fn: T = None, *, topic='', code='', version='', proto='grpc', codec='json', asyncable=True,
-            timeout=10000, meshable=True) -> T:
+def binding(fn: T = None, *, topic='', code='', version='', proto='grpc', codec='json', flags=0, timeout=10000,
+            meshable=True) -> T:
     """
     Multi Provider Service. Mesh provider service.
     :param fn:
@@ -73,9 +73,9 @@ def binding(fn: T = None, *, topic='', code='', version='', proto='grpc', codec=
     :param version:
     :param proto:
     :param codec:
-    :param asyncable:
+    :param flags:
     :param timeout:
     :param meshable:
     :return:
     """
-    return Binding(fn, topic, code, version, proto, codec, asyncable, timeout, meshable)
+    return Binding(fn, topic, code, version, proto, codec, flags, timeout, meshable)
