@@ -3,10 +3,10 @@
 # TRUSTBE PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 #
 #
-
-
+import asyncio
 import inspect
 from abc import abstractmethod
+from asyncio import CancelledError
 from typing import Any, Generic, Type, List, Dict, Callable
 
 from mesh.macro.ark import T
@@ -190,7 +190,18 @@ class Proxy(Generic[T]):
 
     @staticmethod
     def make_delegate(method):
-        def invoke(self, *args, **kwargs):
-            return self.__handler__().invoke(self, method, *args, **kwargs)
+        async def invoke_async(self, *args, **kwargs):
+            return await self.__handler__().invoke(self, method, *args, **kwargs)
 
-        return invoke
+        def invoke(self, *args, **kwargs):
+            r = self.__handler__().invoke(self, method, *args, **kwargs)
+            if not inspect.isawaitable(r):
+                return r
+            try:
+                return asyncio.get_event_loop().run_until_complete(r)
+            except CancelledError as e:
+                raise e.__cause__
+            except BaseException as e:
+                raise e
+
+        return invoke_async if inspect.iscoroutinefunction(method) else invoke
