@@ -5,11 +5,12 @@
 #
 
 from abc import abstractmethod, ABC
-from concurrent.futures import Future
+from typing import Any
 
 from mesh.kinds import Reference
 from mesh.macro import spi
 from mesh.mpc.invoker import Execution
+from mesh.mpc.urn import URN
 
 
 @spi(name="grpc")
@@ -40,13 +41,15 @@ class Consumer(ABC):
         pass
 
     @abstractmethod
-    def consume(self, address: str, urn: str, execution: Execution[Reference], inbound: bytes) -> Future:
+    async def consume(self, address: str, urn: URN, execution: Execution[Reference], inbound: bytes,
+                      args: Any) -> bytes:
         """
         Consume the input payload.
         :param address: Remote address.
         :param urn: Actual uniform resource domain name.
         :param execution: Service reference.
         :param inbound: Input arguments.
+        :param args: Additional arguments.
         :return: Output payload
         """
         pass
