@@ -17,7 +17,7 @@ CONSUMER = "CONSUMER"
 class Filter:
 
     @abstractmethod
-    def invoke(self, invoker: Invoker, invocation: Invocation) -> Any:
+    async def invoke(self, invoker: Invoker, invocation: Invocation) -> Any:
         pass
 
     @staticmethod
@@ -42,9 +42,9 @@ class FilteredInvoker(Invoker[T]):
         self.next_ = next_
         self.filter_ = filter_
 
-    def run(self, invocation: Invocation) -> Any:
-        return self.filter_.invoke(self.next_, invocation)
+    async def run(self, invocation: Invocation) -> Any:
+        return await self.filter_.invoke(self.next_, invocation)
 
 
-def invoke(invoker: Invoker[T], filtering: Filter, invocation: Invocation):
-    return filtering.invoke(invoker, invocation)
+async def invoke(invoker: Invoker[T], filtering: Filter, invocation: Invocation):
+    return await filtering.invoke(invoker, invocation)
