@@ -3,6 +3,7 @@
 # TRUSTBE PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 #
 #
+import inspect
 from typing import Type, Any
 
 from mesh.macro import Inspector, mpi, T
@@ -30,5 +31,8 @@ class MethodInspector(Inspector):
     def get_return_type(self) -> Type[T]:
         return self.method.__annotations__.get("return")
 
-    def invoke(self, obj: Any, args: [Any]) -> Any:
-        return self.method(*args)
+    async def invoke(self, obj: Any, args: [Any]) -> Any:
+        r = self.method(*args)
+        if inspect.isawaitable(r):
+            return await r
+        return r
