@@ -5,7 +5,6 @@
 #
 
 from abc import abstractmethod, ABC
-from asyncio import futures
 from typing import Any, Dict
 from typing import Type, Generic
 
@@ -21,7 +20,7 @@ class Invoker(Generic[T], ABC):
     """
 
     @abstractmethod
-    def run(self, invocation: "Invocation") -> Any:
+    async def run(self, invocation: "Invocation") -> Any:
         pass
 
 
@@ -72,14 +71,6 @@ class Invocation(ABC):
         """ Get the invocation execution. """
         pass
 
-    @abstractmethod
-    def is_futures(self) -> bool:
-        """
-        Is the method return future.
-        :return:
-        """
-        pass
-
     @abstractmethod
     def get_urn(self) -> URN:
         """
@@ -152,11 +143,5 @@ class ServiceInvocation(Generic[T], Invocation):
     def get_execution(self) -> Execution:
         return self.execution
 
-    def is_futures(self) -> bool:
-        rt = self.inspector.get_return_type()
-        if futures.isfuture(rt):
-            return True
-        return False
-
     def get_urn(self) -> URN:
         return self.urn
