@@ -19,7 +19,7 @@ from mesh.mpc.invoker import Invocation, Execution
 from mesh.mpc.service import ServiceInvokeHandler
 from mesh.mpc.service_proxy import ServiceProxy
 from mesh.mpc.urn import URN, URNFlag, MESH_DOMAIN
-from mesh.prsim import Network, RuntimeHook, Subscriber, Registry, Scheduler, Builtin
+from mesh.prsim import RuntimeHook, Subscriber, Registry, Scheduler, Builtin
 
 
 class Provider:
@@ -69,15 +69,15 @@ class Instance(Generic[T], Execution[T]):
     def reflect(self) -> Returns:
         return self.__retype()
 
-    def run(self, invocation: Invocation) -> Any:
-        return self.invoker.run(invocation)
+    async def run(self, invocation: Invocation) -> Any:
+        return await self.invoker.run(invocation)
 
 
 @spi("mesh")
 @binding(topic="mesh.registry.event", code="refresh", meshable=False)
 class MeshEden(Eden, RuntimeHook, Subscriber):
     """
-    Like: create.tenant.omega.json.http2.lx000001.mpi.trustbe.net
+    Like: create.tenant.omega.json.http2.lx000001.mpi.ducesoft.net
     """
 
     def __init__(self):
@@ -90,12 +90,13 @@ class MeshEden(Eden, RuntimeHook, Subscriber):
         self.indies: Dict[Type[T], Dict[mpi, Dict[Any, Instance[Reference]]]] = {}
         self.services: Dict[str, Instance[Service]] = {}
         self.references: Dict[str, Instance[Reference]] = {}
+        self.env = Environ.default()
 
     def define(self, metadata: mpi, reference: Type[T]) -> T:
         return self.make_consumer(metadata, reference)
 
     def refer(self, metadata: mpi, reference: Type[T], method: Inspector) -> Execution[Reference]:
-        return self.make_reference_exec(metadata, reference, self.get_environ()).get(method.get_signature())
+        return self.make_reference_exec(metadata, reference).get(method.get_signature())
 
     def store(self, kind: Type[T], service: Any):
         if not self.providers.get(kind):
@@ -103,7 +104,7 @@ class MeshEden(Eden, RuntimeHook, Subscriber):
         return self.providers.get(kind)
 
     def infer(self, urn: str) -> Execution[Service]:
-        return self.make_service_exec(self.get_environ()).get(URN.parse(urn).name)
+        return self.make_service_exec().get(URN.parse(urn).name)
 
     def refer_types(self) -> List[Type[T]]:
         return list(self.consumers.keys())
@@ -121,7 +122,7 @@ class MeshEden(Eden, RuntimeHook, Subscriber):
             self.consumers[reference][metadata] = Consumer(metadata, reference)
         return self.consumers.get(reference).get(metadata)
 
-    def make_reference_exec(self, md: mpi, ref: Type[T], env: Environ) -> Dict[Any, Instance[Reference]]:
+    def make_reference_exec(self, md: mpi, ref: Type[T]) -> Dict[Any, Instance[Reference]]:
         consumer = self.make_consumer(md, ref)
         if not self.indies.get(ref):
             self.indies[ref] = {}
@@ -129,14 +130,14 @@ class MeshEden(Eden, RuntimeHook, Subscriber):
             executions: Dict[Any, Instance[Reference]] = {}
             for kind, methods in tool.get_declared_methods(ref).items():
                 for method in methods:
-                    refer = self.make_method_as_reference(env, md, kind, method)
+                    refer = self.make_method_as_reference(md, kind, method)
                     instance = Instance(refer.urn, ref, method, consumer.proxy, refer)
                     self.references[refer.urn] = instance
                     executions[instance.inspect().get_signature()] = instance
             self.indies.get(ref)[md] = executions
         return self.indies[ref][md]
 
-    def make_service_exec(self, environ: Environ) -> Dict[str, Instance[Service]]:
+    def make_service_exec(self) -> Dict[str, Instance[Service]]:
         for provider in self.providers.values():
             if provider.making:
                 continue
@@ -145,30 +146,25 @@ class MeshEden(Eden, RuntimeHook, Subscriber):
                     if not hasattr(provider.service, method.__name__):
                         continue
                     mm = getattr(provider.service, method.__name__)
-                    schemas: List[Service] = self.make_schema(environ, provider.kind, kind, method)
+                    schemas: List[Service] = self.make_schema(provider.kind, kind, method)
                     for schema in schemas:
                         urn = URN.parse(schema.urn)
                         self.services[urn.name] = Instance(schema.urn, provider.kind, mm, provider.service, schema)
             provider.making = True
         return self.services
 
-    @staticmethod
-    def get_environ() -> Environ:
-        network = ServiceLoader.load(Network).get_default()
-        return network.get_environ()
-
-    def make_schema(self, environ: Environ, interface: T, kind: T, method: Any) -> List[Service]:
+    def make_schema(self, interface: T, kind: T, method: Any) -> List[Service]:
         schemas = []
         macro = MPS.get_mps_if_present(interface)
         if macro:
-            schemas.append(self.make_mps_as_service(macro, kind, method, environ))
+            schemas.append(self.make_mps_as_service(macro, kind, method))
         bindings = Binding.get_binding_if_present(interface)
         for metadata in bindings:
             if metadata.meshable:
-                schemas = schemas.append(self.make_binding_as_service(metadata, kind, method, environ))
+                schemas = schemas.append(self.make_binding_as_service(metadata, kind, method))
         return schemas
 
-    def make_method_as_reference(self, environ: Environ, metadata: MPI, interface: T, method: Any) -> Reference:
+    def make_method_as_reference(self, metadata: MPI, interface: T, method: Any) -> Reference:
         om = MPI.get_mpi_if_present(method)
         ok = MPI.get_mpi_if_present(interface)
         name = self.choose_if_present(lambda x: x.name, "", om)
@@ -179,7 +175,7 @@ class MeshEden(Eden, RuntimeHook, Subscriber):
         reference.version = self.choose_if_present(lambda x: x.version, '', metadata, om, ok)
         reference.proto = self.choose_if_present(lambda x: x.proto, MeshFlag.GRPC.name, metadata, om, ok)
         reference.codec = self.choose_if_present(lambda x: x.codec, MeshFlag.JSON.name, metadata, om, ok)
-        reference.asyncable = self.choose_if_present(lambda x: x.asyncable, True, metadata, om, ok)
+        reference.flags = self.choose_if_present(lambda x: x.flags, 0, om, ok) | metadata.flags
         reference.timeout = self.choose_if_present(lambda x: x.timeout, 10000, metadata, om, ok)
         reference.retries = self.choose_if_present(lambda x: x.retries, 3, metadata, om, ok)
         reference.node = self.choose_if_present(lambda x: x.node, "", metadata, om, ok)
@@ -189,60 +185,67 @@ class MeshEden(Eden, RuntimeHook, Subscriber):
         reference.cell = self.choose_if_present(lambda x: x.cell, "", metadata, om, ok)
         reference.group = self.choose_if_present(lambda x: x.group, "", metadata, om, ok)
         reference.address = self.choose_if_present(lambda x: x.address, "", metadata, om, ok)
-        reference.urn = self.get_urn(alias, self.get_reference_urn_flag(reference), environ)
+        reference.urn = self.get_urn(alias, self.get_reference_urn_flag(reference))
         return reference
 
-    def make_mps_as_service(self, metadata: MPS, kind: T, method: Any, environ: Environ) -> Service:
+    def make_mps_as_service(self, metadata: MPS, kind: T, method: Any) -> Service:
         om = MPI.get_mpi_if_present(method)
         ok = MPI.get_mpi_if_present(kind)
         name = self.choose_if_present(lambda x: x.name, "", om).replace("${mesh.name}", tool.get_mesh_name()). \
             replace("${mesh.uname}", metadata.name)
         alias = tool.anyone(name, str.lower(f'{kind.__name__}.{method.__name__}'))
-        return self.make_service(environ, kinds.MPS, kind.__name__, method.__name__,
-                                 self.choose_if_present(lambda x: x.proto, MeshFlag.GRPC.name, metadata, om, ok),
-                                 self.choose_if_present(lambda x: x.codec, MeshFlag.JSON.name, metadata, om, ok),
-                                 self.choose_if_present(lambda x: x.version, metadata.version, metadata, om, ok),
-                                 self.choose_if_present(lambda x: x.asyncable, True, metadata, om, ok),
-                                 self.choose_if_present(lambda x: x.timeout, metadata.timeout, metadata, om, ok),
-                                 alias)
-
-    def make_binding_as_service(self, metadata: Binding, kind: T, method: Any, environ: Environ) -> Service:
-        return self.make_service(environ, kinds.Binding, metadata.topic, metadata.code,
-                                 self.choose_if_present(lambda x: x.proto, MeshFlag.GRPC.name, metadata),
-                                 self.choose_if_present(lambda x: x.codec, MeshFlag.JSON.name, metadata),
-                                 metadata.version, metadata.asyncable,
-                                 self.choose_if_present(lambda x: x.timeout, metadata.timeout, metadata),
-                                 str.lower(f'{metadata.topic}.{metadata.code}'))
-
-    def make_service(self, environ: Environ, kind: str, namespace: str, name: str, proto: str, codec: str, version: str,
-                     asyncable: bool, timeout: int, alias: str) -> Service:
-        service = Service()
-        service.namespace = namespace
-        service.name = name
-        service.version = version
-        service.proto = proto
-        service.codec = codec
-        service.asyncable = asyncable
-        service.timeout = timeout
-        service.retries = 0
-        service.node = environ.node_id
-        service.inst = environ.inst_id
-        service.zone = environ.lattice.zone
-        service.cluster = environ.lattice.cluster
-        service.cell = environ.lattice.cell
-        service.group = environ.lattice.group
-        service.address = self.get_listened_address()
-        service.kind = kind
-        service.lang = 'Python3'
-        service.attrs = {}
-        service.urn = self.get_urn(alias, self.get_service_urn_flag(service), environ)
+        service = self.init_service()
+        service.kind = kinds.MPS
+        service.namespace = kind.__name__
+        service.name = method.__name__
+        service.proto = self.choose_if_present(lambda x: x.proto, MeshFlag.GRPC.name, metadata, om, ok)
+        service.codec = self.choose_if_present(lambda x: x.codec, MeshFlag.JSON.name, metadata, om, ok)
+        service.version = self.choose_if_present(lambda x: x.version, metadata.version, metadata, om, ok)
+        service.flags = self.choose_if_present(lambda x: x.flags, 0, om, ok) | metadata.flags
+        service.timeout = self.choose_if_present(lambda x: x.timeout, metadata.timeout, metadata, om, ok)
+        service.urn = self.get_urn(alias, self.get_service_urn_flag(service))
         return service
 
-    @staticmethod
-    def get_urn(alias: str, flag: URNFlag, environ: Environ) -> str:
+    def make_binding_as_service(self, metadata: Binding, kind: T, method: Any) -> Service:
+        service = self.init_service()
+        service.kind = kinds.Binding
+        service.namespace = metadata.topic
+        service.name = metadata.code
+        service.proto = self.choose_if_present(lambda x: x.proto, MeshFlag.GRPC.name, metadata)
+        service.codec = self.choose_if_present(lambda x: x.codec, MeshFlag.JSON.name, metadata)
+        service.version = metadata.version
+        service.flags = metadata.flags
+        service.timeout = self.choose_if_present(lambda x: x.timeout, metadata.timeout, metadata)
+        service.urn = self.get_urn(str.lower(f'{metadata.topic}.{metadata.code}'), self.get_service_urn_flag(service))
+        return service
+
+    def init_service(self) -> Service:
+        service = Service()
+        service.namespace = ''
+        service.name = ''
+        service.version = ''
+        service.proto = ''
+        service.codec = ''
+        service.flags = 0
+        service.timeout = 10000
+        service.retries = 0
+        service.node = self.env.node_id
+        service.inst = self.env.inst_id
+        service.zone = self.env.lattice.zone
+        service.cluster = self.env.lattice.cluster
+        service.cell = self.env.lattice.cell
+        service.group = self.env.lattice.group
+        service.address = self.get_listened_address()
+        service.kind = kinds.MPS
+        service.lang = 'Python3'
+        service.attrs = {}
+        service.urn = ''
+        return service
+
+    def get_urn(self, alias: str, flag: URNFlag) -> str:
         urn = URN()
         urn.domain = MESH_DOMAIN
-        urn.node_id = str.lower(environ.node_id)
+        urn.node_id = str.lower(self.env.node_id)
         urn.name = alias
         urn.flag = flag
         return urn.string()
@@ -310,7 +313,7 @@ class MeshEden(Eden, RuntimeHook, Subscriber):
     def builtin(self) -> Builtin:
         return ServiceLoader.load(Builtin).get_default()
 
-    def start(self):
+    async def start(self):
         for kind, nss in ark.export(mps).items():
             for spec in ark.providers(mps, kind):
                 if not isinstance(spec.metadata, MPS) or inspect.isabstract(spec.kind):
@@ -321,33 +324,36 @@ class MeshEden(Eden, RuntimeHook, Subscriber):
                 except BaseException as e:
                     log.warn(f"Mesh service {kind.__name__} with {e.__str__()}")
 
-        self.task_id = self.scheduler().period(30 * 1000, self.topic)
+        self.task_id = await self.scheduler().period(30 * 1000, self.topic)
 
-    def stop(self):
-        self.scheduler().cancel(self.task_id)
-        self.scheduler().shutdown(3 * 1000)
+    async def stop(self):
+        await self.scheduler().cancel(self.task_id)
+        await self.scheduler().shutdown(3 * 1000)
         metadata = Resource()
         metadata.services = []
         metadata.references = []
         try:
-            self.registry().unregister(self.new_registration(metadata, {}))
+            await self.registry().unregister(self.new_registration(metadata, {}))
         except BaseException as e:
             log.warn("Graceful unregister metadata, {}", str(e))
 
-    def refresh(self):
-        self.start()
+    async def refresh(self):
+        await self.start()
 
-    def subscribe(self, event: Event):
-        v = self.builtin().version()
+    async def wait(self):
+        """"""
+        pass
+
+    async def subscribe(self, event: Event):
+        v = await self.builtin().version()
         version = v if v else Versions()
         attachments = {}
         for k, v in (version.infos if version.infos else {}).items():
             attachments[k] = v
-        environ = self.get_environ()
-        self.make_service_exec(environ)
+        self.make_service_exec()
         for _, consumers in self.consumers.items():
             for _, consumer in consumers.items():
-                self.make_reference_exec(consumer.metadata, consumer.reference, environ)
+                self.make_reference_exec(consumer.metadata, consumer.reference)
         metadata = Resource()
         metadata.services = []
         for _, reference in self.references.items():
@@ -355,4 +361,4 @@ class MeshEden(Eden, RuntimeHook, Subscriber):
         metadata.references = []
         for _, service in self.services.items():
             metadata.references.append(service.resource)
-        self.registry().register(self.new_registration(metadata, attachments))
+        await self.registry().register(self.new_registration(metadata, attachments))
