@@ -16,7 +16,7 @@ class Provider:
     """
 
     @abstractmethod
-    def start(self, address: str, tc: Any):
+    async def start(self, address: str, tc: Any):
         """
         Start the mesh broker.
         :param address:
@@ -26,5 +26,9 @@ class Provider:
         pass
 
     @abstractmethod
-    def close(self):
+    async def close(self):
+        pass
+
+    @abstractmethod
+    async def wait(self):
         pass
