@@ -3,7 +3,8 @@
 # TRUSTBE PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 #
 #
-from asyncio import Future
+import asyncio
+import inspect
 from typing import Any
 
 import mesh.log as log
@@ -19,15 +20,15 @@ class ServiceInvoker(Invoker[T]):
     def __init__(self, service: Any):
         self.service = service
 
-    def run(self, invocation: Invocation) -> Any:
-        result = invocation.get_inspector().invoke(self.service, invocation.get_arguments())
-        if not isinstance(result, Future):
-            return result
+    async def run(self, invocation: Invocation) -> Any:
+        r = await invocation.get_inspector().invoke(self.service, invocation.get_arguments())
+        if not inspect.isawaitable(r):
+            return r
         try:
             eden = ServiceLoader.load(Eden).get_default()
             execution = eden.infer(Mesh.context().get_urn())
             timeout = execution.schema().timeout
-            return result.result(timeout=max(timeout, 3000))
+            return await asyncio.wait_for(r, timeout=max(timeout, 10000))
         except BaseException as e:
             log.error(f'Invoke {Mesh.context().get_urn()} fault because of {e}')
             raise e
@@ -41,5 +42,5 @@ class ServiceInvokeHandler(Invoker):
     def __init__(self, service: Any):
         self.invoker = Filter.composite(ServiceInvoker(service), PROVIDER)
 
-    def run(self, invocation: Invocation) -> Any:
-        return self.invoker.run(invocation)
+    async def run(self, invocation: Invocation) -> Any:
+        return await self.invoker.run(invocation)
