@@ -10,6 +10,8 @@ from mesh.cause import ValidationException
 from mesh.macro import spi, mpi, T, Proxy, MethodProxy
 from mesh.mpc.reference import ReferenceInvokeHandler
 
+HACK = mpi()
+
 
 @spi("mpc")
 class ServiceProxy(MethodProxy):
@@ -19,7 +21,7 @@ class ServiceProxy(MethodProxy):
 
     @staticmethod
     def default_proxy(kind: Type[T]) -> T:
-        return ServiceProxy.static_proxy(kind, mpi())
+        return ServiceProxy.static_proxy(kind, HACK)
 
     @staticmethod
     def static_proxy(kind: Type[T], metadata: mpi) -> T:
