@@ -21,10 +21,10 @@ class MeshRouter(InvocationHandler):
         self.attachments = attachments
         self.address = address
 
-    def invoke(self, proxy: Any, method: Any, *args, **kwargs):
-        return Mesh.context_safe(lambda: self.safe_invoke(proxy, method, *args, **kwargs))
+    async def invoke(self, proxy: Any, method: Any, *args, **kwargs):
+        return await Mesh.context_safe(self.safe_invoke(proxy, method, *args, **kwargs))
 
-    def safe_invoke(self, proxy: Any, method: Any, *args, **kwargs):
+    async def safe_invoke(self, proxy: Any, method: Any, *args, **kwargs):
         overrides = self.get_override_attachments()
         routable = tool.required(self.principal.inst_id) or tool.required(self.principal.node_id)
         try:
@@ -38,8 +38,8 @@ class MeshRouter(InvocationHandler):
 
             executor = getattr(self.reference, method.__name__, method)
             if executor == method:
-                return executor(self.reference, *args, **kwargs)
-            return executor(*args, **kwargs)
+                return await executor(self.reference, *args, **kwargs)
+            return await executor(*args, **kwargs)
         finally:
             for (k, v) in overrides.items():
                 Mesh.context().get_attachments().__setitem__(k, v)
