@@ -24,7 +24,7 @@ CONSUMER = "consumer"
 class Transporter(ABC):
 
     @abstractmethod
-    def transport(self, ctx: Context, urn: str, buff: bytes) -> bytes:
+    async def transport(self, ctx: Context, urn: str, buff: bytes) -> bytes:
         """
         Transport the stream.
         :param ctx:
@@ -45,10 +45,10 @@ class Transporter(ABC):
 @spi(PROVIDER)
 class ProviderTransporter(Transporter):
 
-    def transport(self, ctx: Context, urn: str, buff: bytes) -> bytes:
-        return Mesh.context_safe(lambda: self.transport_safe(ctx, urn, buff))
+    async def transport(self, ctx: Context, urn: str, buff: bytes) -> bytes:
+        return await Mesh.context_safe(self.transport_safe(ctx, urn, buff))
 
-    def transport_safe(self, ctx: Context, uname: str, buff: bytes) -> bytes:
+    async def transport_safe(self, ctx: Context, uname: str, buff: bytes) -> bytes:
         try:
             Mesh.context().rewrite_context(ctx)
             Mesh.context().rewrite_urn(uname)
@@ -61,7 +61,7 @@ class ProviderTransporter(Transporter):
                 outbound.code = MeshCode.NO_SERVICE.code
                 outbound.message = f"No mpi named {urn.name}."
                 return codec.encode(outbound)
-            return self.service(urn, codec, execution, buff)
+            return await self.service(urn, codec, execution, buff)
         except BaseException as e:
             trace_id = Mesh.context().get_trace_id()
             span_id = Mesh.context().get_span_id()
@@ -73,12 +73,12 @@ class ProviderTransporter(Transporter):
             return ServiceLoader.load(Codec).get_default().encode(outbound)
 
     @staticmethod
-    def service(urn: URN, codec: Codec, execution: Execution[Service], buff: bytes) -> bytes:
+    async def service(urn: URN, codec: Codec, execution: Execution[Service], buff: bytes) -> bytes:
         returns = execution.reflect()
         try:
             parameters = codec.decode(buff, execution.intype())
             invocation = ServiceInvocation(execution, execution.inspect(), parameters, execution, urn)
-            result = execution.run(invocation)
+            result = await execution.run(invocation)
             returns.set_code(MeshCode.SUCCESS.get_code())
             returns.set_message(MeshCode.SUCCESS.get_message())
             returns.set_content(result)
@@ -99,6 +99,6 @@ class ProviderTransporter(Transporter):
 @spi(CONSUMER)
 class ConsumerTransporter(Transporter):
 
-    def transport(self, ctx: Context, urn: str, buff: bytes) -> bytes:
+    async def transport(self, ctx: Context, urn: str, buff: bytes) -> bytes:
         Mesh.context().rewrite_context(ctx)
         return b'unknown'
