@@ -15,7 +15,7 @@ class Builtin(ABC):
 
     @abstractmethod
     @mpi("${mesh.name}.builtin.doc")
-    def doc(self, name: str, formatter: str) -> str:
+    async def doc(self, name: str, formatter: str) -> str:
         """
         Export the documents.
         :param name:
@@ -26,7 +26,7 @@ class Builtin(ABC):
 
     @abstractmethod
     @mpi("${mesh.name}.builtin.version")
-    def version(self) -> Versions:
+    async def version(self) -> Versions:
         """
         Get the builtin application version.
         :return:
@@ -35,7 +35,7 @@ class Builtin(ABC):
 
     @abstractmethod
     @mpi("${mesh.name}.builtin.debug")
-    def debug(self, features: Dict[str, str]):
+    async def debug(self, features: Dict[str, str]):
         """
         LogLevel set the application log level.
         :return:
@@ -44,10 +44,28 @@ class Builtin(ABC):
 
     @abstractmethod
     @mpi("${mesh.name}.builtin.stats")
-    def stats(self, features: List[str]) -> Dict[str, str]:
+    async def stats(self, features: List[str]) -> Dict[str, str]:
         """
         Health check stats.
         :param features:
         :return:
         """
         pass
+
+    @abstractmethod
+    @mpi("${mesh.name}.builtin.fallback")
+    async def fallback(self):
+        """
+        Fallback is fallback service
+        """
+        pass
+
+    @abstractmethod
+    @mpi("${mesh.name}.builtin.dump")
+    async def dump(self, names: List[str]) -> Dict[str, str]:
+        """
+        Dump the application data.
+        :param names:
+        :return:
+        """
+        pass
