@@ -13,7 +13,7 @@ class Cluster(ABC):
 
     @abstractmethod
     @mpi("mesh.cluster.election")
-    def election(self, buff: bytes) -> bytes:
+    async def election(self, buff: bytes) -> bytes:
         """
         Election will election leader of instances.
         :param buff:
@@ -23,7 +23,7 @@ class Cluster(ABC):
 
     @abstractmethod
     @mpi("mesh.cluster.leader")
-    def is_leader(self) -> bool:
+    async def is_leader(self) -> bool:
         """
         IsLeader if same level.
         :return:
