@@ -13,8 +13,8 @@ from mesh.macro import mpi
 class Commercialize(ABC):
 
     @abstractmethod
-    @mpi(name="mesh.license.sign", encrypt=True)
-    def sign(self, lsr: License) -> str:
+    @mpi(name="mesh.license.sign", flags=2)
+    async def sign(self, lsr: License) -> str:
         """
         Sign the license.
         :param lsr:
@@ -23,8 +23,8 @@ class Commercialize(ABC):
         pass
 
     @abstractmethod
-    @mpi(name="mesh.license.history", encrypt=True)
-    def history(self, inst_id: str) -> List[CommerceLicense]:
+    @mpi(name="mesh.license.history", flags=2)
+    async def history(self, inst_id: str) -> List[CommerceLicense]:
         """
         History list the licenses.
         :param inst_id:
@@ -33,8 +33,8 @@ class Commercialize(ABC):
         pass
 
     @abstractmethod
-    @mpi(name="mesh.net.issued", encrypt=True)
-    def issued(self, name: str, kind: str) -> CommerceEnviron:
+    @mpi(name="mesh.net.issued", flags=2)
+    async def issued(self, name: str, kind: str) -> CommerceEnviron:
         """
         Issued mesh node identity.
         :param name:
@@ -44,8 +44,8 @@ class Commercialize(ABC):
         pass
 
     @abstractmethod
-    @mpi(name="mesh.net.dump", encrypt=True)
-    def issued(self, node_id: str) -> List[CommerceEnviron]:
+    @mpi(name="mesh.net.dump", flags=2)
+    async def issued(self, node_id: str) -> List[CommerceEnviron]:
         """
         Dump the node identity.
         :param node_id:
