@@ -39,6 +39,10 @@ class RunMode(Enum):
     """
     Mock模式
     """
+    TRACE = 64
+    """
+    追踪模式
+    """
 
     def is_debug(self) -> bool:
         return RunMode.matches(RunMode.DEBUG, self.value)
@@ -58,6 +62,9 @@ class RunMode(Enum):
     def is_mock(self) -> bool:
         return RunMode.matches(RunMode.MOCK, self.value)
 
+    def match(self, code: int) -> bool:
+        return (self.value & code) == self.value
+
     @staticmethod
     def matches(mode: Any, code: int):
         return isinstance(mode, RunMode) and (mode.value & code) is code
@@ -177,7 +184,7 @@ class Context(ABC):
         pass
 
     @abstractmethod
-    def get_run_mode(self) -> RunMode:
+    def get_run_mode(self) -> int:
         """
         Get the request run mode. RunMode
         :return: The request run mode.
@@ -187,7 +194,7 @@ class Context(ABC):
     @abstractmethod
     def get_urn(self) -> str:
         """
-        Mesh resource uniform name. Like: create.tenant.omega.json.http2.lx000001.mpi.trustbe.net
+        Mesh resource uniform name. Like: create.tenant.omega.json.http2.lx000001.mpi.ducesoft.net
         :return: Uniform name.
         """
         pass
@@ -277,6 +284,22 @@ class Context(ABC):
         """
         pass
 
+    @abstractmethod
+    def encode(self) -> Dict[str, str]:
+        """
+        Encode context to string.
+        :return:
+        """
+        pass
+
+    @abstractmethod
+    def decode(self, attachments: Dict[str, str]) -> None:
+        """
+        Decode context from string.
+        :return:
+        """
+        pass
+
 
 class Queue(Deque, Generic[T]):
     def pop(self) -> T:
