@@ -16,7 +16,7 @@ class DataHouse(ABC):
 
     @abstractmethod
     @mpi("mesh.dh.writes")
-    def writes(self, docs: List[Document]):
+    async def writes(self, docs: List[Document]):
         """
         batch write log message
         :param docs:
@@ -26,7 +26,7 @@ class DataHouse(ABC):
 
     @abstractmethod
     @mpi("mesh.dh.write")
-    def write(self, doc: Document):
+    async def write(self, doc: Document):
         """
         write log message
         :param doc:
@@ -36,7 +36,7 @@ class DataHouse(ABC):
 
     @abstractmethod
     @mpi("mesh.dh.read")
-    def read(self, index: Paging) -> Page[Any]:
+    async def read(self, index: Paging) -> Page[Any]:
         """
         write log message
         :param index:
@@ -46,7 +46,7 @@ class DataHouse(ABC):
 
     @abstractmethod
     @mpi("mesh.dh.indies")
-    def indies(self, index: Paging) -> Page[Any]:
+    async def indies(self, index: Paging) -> Page[Any]:
         """
         Export index list.
         :param index:
@@ -56,7 +56,7 @@ class DataHouse(ABC):
 
     @abstractmethod
     @mpi("mesh.dh.tables")
-    def tables(self, index: Paging) -> Page[Any]:
+    async def tables(self, index: Paging) -> Page[Any]:
         """
         Export table list.
         :param index:
