@@ -14,7 +14,7 @@ from mesh.macro import spi, T
 class Dispatcher(ABC):
 
     @abstractmethod
-    def reference(self, mpi: Type[T]) -> T:
+    async def reference(self, mpi: Type[T]) -> T:
         """
         Refer an generic dispatcher.
         :param mpi:
@@ -23,7 +23,7 @@ class Dispatcher(ABC):
         pass
 
     @abstractmethod
-    def invoke(self, urn: str, param: Dict[str, Any]) -> Any:
+    async def invoke(self, urn: str, param: Dict[str, Any]) -> Any:
         """
         Dispatch generic invoke with urn.
         :param urn:
@@ -33,7 +33,7 @@ class Dispatcher(ABC):
         pass
 
     @abstractmethod
-    def invoke_generic(self, urn: str, param: Any) -> Any:
+    async def invoke_generic(self, urn: str, param: Any) -> Any:
         """
         Dispatch generic invoke with urn and generic params.
         :param urn:
