@@ -17,7 +17,7 @@ class Endpoint(ABC):
 
     @abstractmethod
     @mpi("${mesh.uname}")
-    def fuzzy(self, buff: bytes) -> bytes:
+    async def fuzzy(self, buff: bytes) -> bytes:
         """
         Invoke endpoint.
         :param buff:
@@ -33,7 +33,7 @@ class EndpointSticker(ABC, Generic[T, A]):
     """
 
     @abstractmethod
-    def stick(self, varg: T) -> A:
+    async def stick(self, varg: T) -> A:
         """
         Invoke endpoint.
         :param varg:
