@@ -18,7 +18,7 @@ class Evaluator(ABC, Generic[T, A]):
 
     @abstractmethod
     @mpi("mesh.eval.compile")
-    def compile(self, script: Script) -> str:
+    async def compile(self, script: Script) -> str:
         """
         Compile the named rule.
         :param script:
@@ -27,7 +27,7 @@ class Evaluator(ABC, Generic[T, A]):
 
     @abstractmethod
     @mpi("mesh.eval.exec")
-    def exec(self, code: str, args: Any, dft: str) -> str:
+    async def exec(self, code: str, args: Any, dft: str) -> str:
         """
         Exec the script with name.
         :param code:
@@ -38,7 +38,7 @@ class Evaluator(ABC, Generic[T, A]):
 
     @abstractmethod
     @mpi("mesh.eval.dump")
-    def dump(self, feature: Dict[str, str]) -> List[Script]:
+    async def dump(self, feature: Dict[str, str]) -> List[Script]:
         """
         Dump the scripts.
         :param feature:
@@ -47,7 +47,7 @@ class Evaluator(ABC, Generic[T, A]):
 
     @abstractmethod
     @mpi("mesh.eval.index")
-    def index(self, index: Paging) -> Page[Script]:
+    async def index(self, index: Paging) -> Page[Script]:
         """
         Dump the scripts.
         :param index:
