@@ -16,7 +16,7 @@ class Graphics(ABC):
 
     @abstractmethod
     @mpi("mesh.graphics.captcha.apply")
-    def captcha(self, kind: str, features: Dict[str, str]) -> Captcha:
+    async def captcha(self, kind: str, features: Dict[str, str]) -> Captcha:
         """
         Apply a graphics captcha.
         :param kind:
@@ -27,7 +27,7 @@ class Graphics(ABC):
 
     @abstractmethod
     @mpi("mesh.graphics.captcha.verify")
-    def verify(self, mno: str, value: str) -> bool:
+    async def verify(self, mno: str, value: str) -> bool:
         """
         Verify a graphics captcha value.
         :param mno:
