@@ -14,7 +14,7 @@ from mesh.macro import spi
 class Hodor(ABC):
 
     @abstractmethod
-    def stats(self, features: List[str]) -> Dict[str, str]:
+    async def stats(self, features: List[str]) -> Dict[str, str]:
         """
         Collect the system, application, process or thread status etc.
         :param features: customized parameters
@@ -23,7 +23,7 @@ class Hodor(ABC):
         pass
 
     @abstractmethod
-    def debug(self, features: Dict[str, str]):
+    async def debug(self, features: Dict[str, str]):
         """
         Set debug features.
         :param features:
