@@ -15,7 +15,7 @@ class IOStream(ABC):
 
     @abstractmethod
     @mpi(name="${mesh.name}.io.page.read", timeout=60000)
-    def read(self, index: Paging) -> Page[bytes]:
+    async def read(self, index: Paging) -> Page[bytes]:
         """
         Read storage with page.
         :param index:
@@ -25,7 +25,7 @@ class IOStream(ABC):
 
     @abstractmethod
     @mpi(name="${mesh.name}.io.page.write", timeout=60000)
-    def write(self, index: Page[bytes]):
+    async def write(self, index: Page[bytes]):
         """
         Write storage with page.
         :param index:
