@@ -16,7 +16,7 @@ class KV(ABC):
 
     @abstractmethod
     @mpi("mesh.kv.get")
-    def get(self, key: str) -> Entity:
+    async def get(self, key: str) -> Entity:
         """
         Get the value from kv store.
         :param key:
@@ -26,7 +26,7 @@ class KV(ABC):
 
     @abstractmethod
     @mpi("mesh.kv.put")
-    def put(self, key: str, value: Entity):
+    async def put(self, key: str, value: Entity):
         """
         Put the value to kv store.
         :param key:
@@ -37,28 +37,28 @@ class KV(ABC):
 
     @abstractmethod
     @mpi("mesh.kv.remove")
-    def remove(self):
+    async def remove(self):
         """
         Remove the kv store.
         :return:
         """
         pass
 
-    def get_with_type(self, key: str, kind: Type[T]) -> T:
+    async def get_with_type(self, key: str, kind: Type[T]) -> T:
         """
         Get by codec.
         :param key:
         :param kind:
         :return:
         """
-        entity = self.get(key)
+        entity = await self.get(key)
         return entity.try_read_object(kind) if entity else None
 
-    def put_object(self, key: str, value: Any):
+    async def put_object(self, key: str, value: Any):
         """
         Put by codec.
         :param key:
         :param value:
         :return:
         """
-        self.put(key, Entity.wrap(value))
+        await self.put(key, Entity.wrap(value))
