@@ -13,8 +13,8 @@ from mesh.macro import mpi
 class Licenser(ABC):
 
     @abstractmethod
-    @mpi(name="mesh.license.imports", encrypt=True)
-    def imports(self, text: str):
+    @mpi(name="mesh.license.imports", flags=2)
+    async def imports(self, text: str):
         """
         Import the license.
         :param text:
@@ -23,8 +23,8 @@ class Licenser(ABC):
         pass
 
     @abstractmethod
-    @mpi(name="mesh.license.exports", encrypt=True)
-    def exports(self) -> str:
+    @mpi(name="mesh.license.exports", flags=2)
+    async def exports(self) -> str:
         """
         Exports the license.
         :return:
@@ -32,8 +32,8 @@ class Licenser(ABC):
         pass
 
     @abstractmethod
-    @mpi(name="mesh.license.explain", encrypt=True)
-    def explain(self) -> License:
+    @mpi(name="mesh.license.explain", flags=2)
+    async def explain(self) -> License:
         """
         Explain the license.
         :return:
@@ -41,8 +41,8 @@ class Licenser(ABC):
         pass
 
     @abstractmethod
-    @mpi(name="mesh.license.verify", encrypt=True)
-    def verify(self) -> bool:
+    @mpi(name="mesh.license.verify", flags=2)
+    async def verify(self) -> bool:
         """
         Verify the license.
         :return:
@@ -50,8 +50,8 @@ class Licenser(ABC):
         pass
 
     @abstractmethod
-    @mpi(name="mesh.license.features", encrypt=True)
-    def features(self) -> Dict[str, str]:
+    @mpi(name="mesh.license.features", flags=2)
+    async def features(self) -> Dict[str, str]:
         """
         License features.
         :return:
