@@ -14,7 +14,7 @@ class Locker(ABC):
 
     @abstractmethod
     @mpi("mesh.locker.w.lock")
-    def lock(self, rid: str, timeout: int) -> bool:
+    async def lock(self, rid: str, timeout: int) -> bool:
         """
         Acquires the lock.
         :param rid:
@@ -25,7 +25,7 @@ class Locker(ABC):
 
     @abstractmethod
     @mpi("mesh.locker.w.unlock")
-    def unlock(self, rid: str):
+    async def unlock(self, rid: str):
         """
         Releases the lock.
         :return:
@@ -34,7 +34,7 @@ class Locker(ABC):
 
     @abstractmethod
     @mpi("mesh.locker.r.lock")
-    def read_lock(self, rid: str, timeout: int) -> bool:
+    async def read_lock(self, rid: str, timeout: int) -> bool:
         """
         Create a sample lock.
         :param rid:
@@ -45,7 +45,7 @@ class Locker(ABC):
 
     @abstractmethod
     @mpi("mesh.locker.r.unlock")
-    def read_unlock(self, rid: str):
+    async def read_unlock(self, rid: str):
         """
         Create a sample lock.
         :param rid:
