@@ -16,7 +16,7 @@ class Registry(ABC):
 
     @abstractmethod
     @mpi("mesh.registry.put")
-    def register(self, registration: Registration):
+    async def register(self, registration: Registration):
         """
         Register metadata to mesh graph database.
         :param registration:
@@ -26,7 +26,7 @@ class Registry(ABC):
 
     @abstractmethod
     @mpi("mesh.registry.puts")
-    def registers(self, registrations: List[Registration]):
+    async def registers(self, registrations: List[Registration]):
         """
         Register metadata to mesh graph database.
         :param registrations:
@@ -36,7 +36,7 @@ class Registry(ABC):
 
     @abstractmethod
     @mpi("mesh.registry.remove")
-    def unregister(self, registration: Registration):
+    async def unregister(self, registration: Registration):
         """
         Unregister metadata from mesh graph database.
         :param registration:
@@ -46,7 +46,7 @@ class Registry(ABC):
 
     @abstractmethod
     @mpi("mesh.registry.export")
-    def export(self, kind: str) -> List[Registration]:
+    async def export(self, kind: str) -> List[Registration]:
         """
         Export register metadata of mesh graph database.
         :param kind:
