@@ -15,6 +15,9 @@ from mesh.macro import T, ServiceLoader, spi
 @spi("mesh")
 class Routable(ABC, Generic[T]):
 
+    def __call__(self, *args, **kwargs):
+        return self
+
     @abstractmethod
     def __init__(self, reference: T = None, attachments: Dict[str, str] = None, address: str = ""):
         pass
