@@ -12,7 +12,7 @@ from mesh.macro import spi
 class RuntimeHook(ABC):
 
     @abstractmethod
-    def start(self):
+    async def start(self):
         """
          Trigger when mesh runtime is start.
         :return:
@@ -20,7 +20,7 @@ class RuntimeHook(ABC):
         pass
 
     @abstractmethod
-    def stop(self):
+    async def stop(self):
         """
         Trigger when mesh runtime is stop.
         :return:
@@ -28,9 +28,17 @@ class RuntimeHook(ABC):
         pass
 
     @abstractmethod
-    def refresh(self):
+    async def refresh(self):
         """
         Trigger then mesh runtime context is refresh or metadata is refresh.
         :return:
         """
         pass
+
+    @abstractmethod
+    async def wait(self):
+        """
+        Wait for mesh runtime is terminal.
+        :return:
+        """
+        pass
