@@ -16,7 +16,7 @@ class Scheduler(ABC):
 
     @abstractmethod
     @mpi("mesh.schedule.timeout")
-    def timeout(self, timeout: Timeout, duration: int) -> str:
+    async def timeout(self, timeout: Timeout, duration: int) -> str:
         """
         Schedules the specified {@link Timeout} for one-time execution after
         the specified delay.
@@ -28,7 +28,7 @@ class Scheduler(ABC):
 
     @abstractmethod
     @mpi("mesh.schedule.cron")
-    def cron(self, cron: str, binding: Topic) -> str:
+    async def cron(self, cron: str, binding: Topic) -> str:
         """
         Schedules with the cron expression. "0 * * 1-3 * ? *"
         :param cron:
@@ -39,7 +39,7 @@ class Scheduler(ABC):
 
     @abstractmethod
     @mpi("mesh.schedule.period")
-    def period(self, duration: int, binding: Topic) -> str:
+    async def period(self, duration: int, binding: Topic) -> str:
         """
         Releases all resources acquired by this {@link Scheduler} and cancels all
         tasks which were scheduled but not executed yet.
@@ -51,7 +51,7 @@ class Scheduler(ABC):
 
     @abstractmethod
     @mpi("mesh.schedule.dump")
-    def dump(self) -> List[str]:
+    async def dump(self) -> List[str]:
         """
         Dump all taskIds, only effected in pvm.
         :return:
@@ -60,7 +60,7 @@ class Scheduler(ABC):
 
     @abstractmethod
     @mpi("mesh.schedule.cancel")
-    def cancel(self, task_id: str) -> bool:
+    async def cancel(self, task_id: str) -> bool:
         """
         Cancel the pending tasks.
         :param task_id:
@@ -70,7 +70,7 @@ class Scheduler(ABC):
 
     @abstractmethod
     @mpi("mesh.schedule.stop")
-    def stop(self, task_id: str) -> bool:
+    async def stop(self, task_id: str) -> bool:
         """
         Stop the pending tasks.
         :param task_id:
@@ -80,7 +80,7 @@ class Scheduler(ABC):
 
     @abstractmethod
     @mpi("mesh.schedule.emit")
-    def emit(self, binding: Topic) -> bool:
+    async def emit(self, binding: Topic) -> bool:
         """
         Shutdown the scheduler.
         :param binding:
@@ -90,7 +90,7 @@ class Scheduler(ABC):
 
     @abstractmethod
     @mpi("mesh.schedule.shutdown")
-    def shutdown(self, duration: int) -> bool:
+    async def shutdown(self, duration: int) -> bool:
         """
         Shutdown the scheduler.
         :param duration:
