@@ -14,7 +14,7 @@ class Sequence(ABC):
 
     @abstractmethod
     @mpi("mesh.sequence.next")
-    def next(self, kind: str, length: int) -> str:
+    async def next(self, kind: str, length: int) -> str:
         """
         Generate a unique number in network.
         :param kind:
@@ -25,7 +25,7 @@ class Sequence(ABC):
 
     @abstractmethod
     @mpi("mesh.sequence.section")
-    def section(self, kind: str, size: int, length: int) -> List[str]:
+    async def section(self, kind: str, size: int, length: int) -> List[str]:
         """
         Generate some unique number in network as s section.
         :param kind:
