@@ -15,7 +15,7 @@ class Subscriber(ABC):
 
     @abstractmethod
     @mpi("mesh.queue.subscribe")
-    def subscribe(self, event: Event):
+    async def subscribe(self, event: Event):
         """
         Subscribe the event with {@link com.be.mesh.client.annotate.Bindings} or {@link com.be.mesh.client.annotate.Binding}
         :param event:
