@@ -13,7 +13,7 @@ class Tokenizer(ABC):
 
     @abstractmethod
     @mpi("mesh.trust.apply")
-    def apply(self, kind: str, duration: int) -> str:
+    async def apply(self, kind: str, duration: int) -> str:
         """
         Apply a node token.
         :param kind:
@@ -24,7 +24,7 @@ class Tokenizer(ABC):
 
     @abstractmethod
     @mpi("mesh.trust.verify")
-    def verify(self, token: str) -> bool:
+    async def verify(self, token: str) -> bool:
         """
         Verify some token verifiable.
         :param token:
