@@ -21,7 +21,7 @@ class Transport(ABC, Generic[T]):
 
     @abstractmethod
     @mpi("mesh.chan.open")
-    def open(self, session_id: str, metadata: Dict[str, str]) -> "Session":
+    async def open(self, session_id: str, metadata: Dict[str, str]) -> "Session":
         """
         Open a channel session.
         :param session_id:  node id or inst id
@@ -32,7 +32,7 @@ class Transport(ABC, Generic[T]):
 
     @abstractmethod
     @mpi("mesh.chan.close")
-    def close(self, timeout: int):
+    async def close(self, timeout: int):
         """
         Close the channel.
         :return:
@@ -41,7 +41,7 @@ class Transport(ABC, Generic[T]):
 
     @abstractmethod
     @mpi("mesh.chan.roundtrip")
-    def roundtrip(self, payload: bytes, metadata: Dict[str, str]) -> bytes:
+    async def roundtrip(self, payload: bytes, metadata: Dict[str, str]) -> bytes:
         """
         Roundtrip with the channel.
         :param payload:
@@ -59,7 +59,7 @@ class Session(ABC, Generic[T]):
 
     @abstractmethod
     @mpi("mesh.chan.peek")
-    def peek(self, topic: str = "") -> bytes:
+    async def peek(self, topic: str = "") -> bytes:
         """
         Retrieves, but does not remove, the head of this queue,
         or returns None if this queue is empty.
@@ -71,7 +71,7 @@ class Session(ABC, Generic[T]):
 
     @abstractmethod
     @mpi(name="mesh.chan.pop", timeout=120 * 1000)
-    def pop(self, timeout: int, topic: str = "") -> bytes:
+    async def pop(self, timeout: int, topic: str = "") -> bytes:
         """
         Retrieves and removes the head of this queue,
         or returns None if this queue is empty.
@@ -83,7 +83,7 @@ class Session(ABC, Generic[T]):
 
     @abstractmethod
     @mpi("mesh.chan.push")
-    def push(self, payload: bytes, metadata: Dict[str, str], topic: str = ""):
+    async def push(self, payload: bytes, metadata: Dict[str, str], topic: str = ""):
         """
         Inserts the specified element into this queue if it is possible to do
         so immediately without violating capacity restrictions.
@@ -99,7 +99,7 @@ class Session(ABC, Generic[T]):
 
     @abstractmethod
     @mpi("mesh.chan.release")
-    def release(self, timeout: int, topic: str = ""):
+    async def release(self, timeout: int, topic: str = ""):
         """
         Close the channel session.
         :param timeout:
@@ -107,15 +107,3 @@ class Session(ABC, Generic[T]):
         :return:
         """
         pass
-
-    async def pick(self, topic: str = "") -> bytes:
-        """ Peek the instance """
-        return self.peek(topic)
-
-    async def poll(self, timeout: int, topic: str = "") -> bytes:
-        """ Pop the instance """
-        return self.pop(timeout, topic)
-
-    async def offer(self, payload: bytes, metadata: Dict[str, str], topic: str = ""):
-        """ Push the instance """
-        self.push(payload, metadata, topic)
