@@ -14,8 +14,8 @@ class MeshCluster(Cluster):
     def __init__(self):
         self.proxy = ServiceProxy.default_proxy(Cluster)
 
-    def election(self, buff: bytes) -> bytes:
-        return self.proxy.election(buff)
+    async def election(self, buff: bytes) -> bytes:
+        return await self.proxy.election(buff)
 
-    def is_leader(self) -> bool:
-        return self.proxy.is_leader()
+    async def is_leader(self) -> bool:
+        return await self.proxy.is_leader()
