@@ -12,11 +12,11 @@ from mesh.prsim import Dispatcher
 @spi("mesh")
 class MeshDispatcher(Dispatcher):
 
-    def reference(self, mpi: Type[T]) -> T:
+    async def reference(self, mpi: Type[T]) -> T:
         pass
 
-    def invoke(self, urn: str, param: Dict[str, Any]) -> Any:
+    async def invoke(self, urn: str, param: Dict[str, Any]) -> Any:
         pass
 
-    def invoke_generic(self, urn: str, param: Any) -> Any:
+    async def invoke_generic(self, urn: str, param: Any) -> Any:
         pass
