@@ -10,8 +10,8 @@ from mesh.prsim import Endpoint, EndpointSticker
 @mps
 class MeshEndpoint(Endpoint, EndpointSticker[bytes, bytes]):
 
-    def fuzzy(self, buff: bytes) -> bytes:
+    async def fuzzy(self, buff: bytes) -> bytes:
         pass
 
-    def stick(self, varg: bytes) -> bytes:
+    async def stick(self, varg: bytes) -> bytes:
         pass
