@@ -17,14 +17,14 @@ class MeshEvaluator(Evaluator):
     def __init__(self):
         self.evaluator = ServiceProxy.default_proxy(Evaluator)
 
-    def compile(self, script: Script) -> str:
-        return self.evaluator.compile(script)
+    async def compile(self, script: Script) -> str:
+        return await self.evaluator.compile(script)
 
-    def exec(self, code: str, args: Any, dft: str) -> str:
-        return self.evaluator.exec(code, args, dft)
+    async def exec(self, code: str, args: Any, dft: str) -> str:
+        return await self.evaluator.exec(code, args, dft)
 
-    def dump(self, feature: Dict[str, str]) -> List[Script]:
-        return self.evaluator.dump(feature)
+    async def dump(self, feature: Dict[str, str]) -> List[Script]:
+        return await self.evaluator.dump(feature)
 
-    def index(self, index: Paging) -> Page[Script]:
-        return self.evaluator.index(index)
+    async def index(self, index: Paging) -> Page[Script]:
+        return await self.evaluator.index(index)
