@@ -13,9 +13,9 @@ from mesh.prsim import Hodor
 @spi("mesh")
 class MeshHodor(Hodor):
 
-    def stats(self, features: List[str]) -> Dict[str, str]:
+    async def stats(self, features: List[str]) -> Dict[str, str]:
         return {"status": "true"}
 
-    def debug(self, features: Dict[str, str]):
+    async def debug(self, features: Dict[str, str]):
         """ debug """
         pass
