@@ -17,8 +17,8 @@ class MeshPublisher(Publisher):
     def __init__(self):
         self.proxy = ServiceProxy.default_proxy(Publisher)
 
-    def publish(self, events: List[Event]) -> List[str]:
-        return self.proxy.publish(events)
+    async def publish(self, events: List[Event]) -> List[str]:
+        return await self.proxy.publish(events)
 
-    def broadcast(self, events: List[Event]) -> List[str]:
-        return self.proxy.broadcast(events)
+    async def broadcast(self, events: List[Event]) -> List[str]:
+        return await self.proxy.broadcast(events)
