@@ -17,14 +17,14 @@ class MeshRegistry(Registry):
     def __init__(self):
         self.proxy = ServiceProxy.default_proxy(Registry)
 
-    def register(self, registration: Registration):
-        return self.proxy.register(registration)
+    async def register(self, registration: Registration):
+        return await self.proxy.register(registration)
 
-    def registers(self, registrations: List[Registration]):
-        return self.proxy.registers(registrations)
+    async def registers(self, registrations: List[Registration]):
+        return await self.proxy.registers(registrations)
 
-    def unregister(self, registration: Registration):
-        return self.proxy.unregister(registration)
+    async def unregister(self, registration: Registration):
+        return await self.proxy.unregister(registration)
 
-    def export(self, kind: str) -> List[Registration]:
-        return self.proxy.export()
+    async def export(self, kind: str) -> List[Registration]:
+        return await self.proxy.export()
