@@ -3,6 +3,7 @@
 # TRUSTBE PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 #
 #
+
 from mesh.macro import spi
 from mesh.prsim import RuntimeHook
 
@@ -10,14 +11,18 @@ from mesh.prsim import RuntimeHook
 @spi("mesh")
 class MeshRuntimeHook(RuntimeHook):
 
-    def start(self):
+    async def start(self):
         """"""
         pass
 
-    def stop(self):
+    async def stop(self):
         """"""
         pass
 
-    def refresh(self):
+    async def refresh(self):
+        """"""
+        pass
+
+    async def wait(self):
         """"""
         pass
