@@ -6,7 +6,7 @@
 
 import unittest
 from abc import ABC, abstractmethod
-from typing import Any
+from typing import Coroutine
 
 from mesh.kinds import Principal
 from mesh.macro import mpi, mps
@@ -39,16 +39,19 @@ class TestServiceInvoke(unittest.TestCase):
         ret = self.service.foo("Terminator")
         self.assertEqual(ret, "I am Terminator")
 
-    def test_context_safe(self):
-        Mesh.context_safe(
-            lambda: TestServiceInvoke.phase(
-                lambda: TestServiceInvoke.phase(lambda: TestServiceInvoke.phase(lambda: print(-1)))))
+    @staticmethod
+    async def print():
+        print(-1)
+
+    async def test_context_safe(self):
+        await Mesh.context_safe(
+            TestServiceInvoke.phase(TestServiceInvoke.phase(TestServiceInvoke.phase(self.print()))))
         print(len(Mesh.context().get_principals()))
 
     @staticmethod
-    def phase(fn: Any):
+    async def phase(fn: Coroutine):
         Mesh.context().get_principals().append(Principal())
-        Mesh.context_safe(fn)
+        await Mesh.context_safe(fn)
         print(len(Mesh.context().get_principals()))
 
 
