@@ -81,6 +81,10 @@ def get_min_channels() -> int:
     return System.environ().get_min_channels()
 
 
+def get_proc() -> int:
+    return System.environ().get_proc()
+
+
 def required(*args: Any) -> bool:
     if not args:
         return False
